# NAME:
#	csh.login - global initialization for csh
#
# DESCRIPTION:
#	This file is processed during login by /bin/csh
#	The idea is to provide central management of the
#	operating environment for C-shell users.  While some
#	versions of the C-shell will automatically process this
#	file, others require the users $HOME/.login file to
#	contain the line:
#		source /etc/csh.login
#	The user's .login file can of course override any of
#	these defaults if needed.
#	NOTE that this file is processed "after" /etc/csh.cshrc
#
# SEE ALSO:
#	$HOME/.login
#	/etc/csh.cshrc
#
#
# BUGS:
#	I stopped using csh in about 1990, so I doubt that this
#	produces quite the same environment as my /etc/profile and
#	/etc/ksh.kshrc
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: csh.login,v 1.8 2001/08/30 09:55:53 sjg Exp $
#
#	@(#)Copyright (c) 1991 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 

# set some useful variables for everyone

# csh can't do this...
setenv LOCAL_DIRS `/bin/sh -c "/bin/ls -ld /local /usr/local 2>/dev/null" | awk '{ print $NF }' | sort -u`

setenv SHELL /bin/csh

# you need to set this manually for SCO-UNIX
# since their `uname -s` returns the 
# same string as `uname -n`
# setenv OS SCO-UNIX
setenv OS `uname`
setenv MACHINE `uname -m`
setenv OSREL `uname -r`
setenv OSMAJOR `echo $OSREL | cut -d. -f1`

set noglob
switch ($OS)
case SunOS:
	switch ($OSREL)
	case 4.0:
		# uname -m just says sun - great
		setenv MACHINE `arch`
		breaksw
	endsw
	breaksw
endsw


# pick one of the following for the default umask
 umask 002	# relaxed	-rwxrwxr-x
# umask 022	# cautious	-rwxr-xr-x
# umask 027	# uptight	-rwxr-x---
# umask 077	# paranoid	-rwx------

if ($?prompt) then
	# we are interactive
	# $tty is set for each csh by csh.cshrc
	# $TTY is used to record the tty we logged in on
	# since csh.cshrc has already been processed we
	# can simply set TTY=$tty
	if (! $?tty ) setenv tty `tty | sed 's,/dev/,,'`

	setenv TTY $tty

	setenv OS_DIRS ""
	setenv X `echo -n .`
	switch ($X)
	case -n*:
		setenv N ""
		setenv C "\c"
		breaksw
	default:
		setenv N "-n"
		setenv C ""
		breaksw
	endsw
	unsetenv X

	# we could use stty sane, but that fiddles parenb etc
	stty isig icanon intr '^c' erase '^h' kill '^u' eof '^d' echoe echok

	foreach d ( /var/mail /var/spool/mail /usr/spool/mail )
		if ( -d $d ) then
			setenv MAIL $d/$USER
			break
		endif
	end

	# handle operating system specific things
	# ie. this can cater for all SunOS systems
	# where as $MACHINE_ARCH caters for differences b/w
	# sun386, sun4c etc 
	switch ($OS)
	case SunOS:
		# On sun's /bin -> /usr/bin so leave it out!
		set path=( /usr/bin /usr/ucb )
		set path=(`/etc/set_paths.sh /usr/sbin /usr/5bin /usr/etc`)
		setenv LD_LIBRARY_PATH `/etc/set_paths.sh -P LD_LIBRARY_PATH \
		/usr/lib /usr/snm/lib \
		/usr/X11R6/lib /usr/X11R5/lib /usr/openwin/lib \
		/opt/SUNWconn/snm/lib `

		# handle architecture specific items
		switch ($MACHINE)
		case sun386:	# some sun386i only items
			# X/Open language code
			setenv LANG USA-English
			setenv DOS_CMDTOOL off
			setenv AUTOMOUNT_FIXNAMES true
			breaksw
		endsw
		switch ($OSREL)
		case 5*:
			unset noglob
			set path=( $path /opt/SUN*/bin )
			set noglob
			breaksw
		endsw
		if (! $?dterm ) setenv dterm vt220
		setenv MANPATH /usr/man
		breaksw
	case B.O.S.:	# Bull DPX/2
		if (! $?dterm ) setenv dterm vt220
		setenv MANPATH /usr/catman
		breaksw
	case SCO-UNIX:	# SCO UNIX
		if (! $?dterm ) setenv dterm ansi
		setenv MANPATH /usr/man
		breaksw
	endsw

	setenv OS_DIRS "$OS_DIRS $OS/$OSMAJOR.X/$MACHINE $OS/$OSMAJOR.X $OS"
	setenv OS_BIN ""
	setenv OS_MAN ""

	foreach top ( $LOCAL_DIRS /net /net/local )
		if (! $?LOCAL ) setenv LOCAL $top

		foreach d ( share $OS_DIRS )
			setenv OS_BIN "$OS_BIN $top/$d/bin $top/$d/sbin"
			setenv OS_MAN "$OS_MAN $top/$d/man"
		end
		setenv OS_BIN "$OS_BIN $top/bin $top/sbin"
		setenv OS_MAN "$OS_MAN $top/man"
	end

	# now add a bunch of dirs that may or may not exists
	set path=(`/etc/set_paths.sh  /usr/ucb /usr/lbin /usr/ccs/bin $OS_BIN /usr/bin/X11 /usr/X11R6/bin /usr/X11R5/bin /usr/X386/bin /usr/openwin/bin /opt/gnu/bin`)

	setenv MANPATH `/etc/set_paths.sh -P MANPATH /usr/X11R6/man /usr/X11R5/man /usr/X386/man ${OS_MAN}`


	if ( -e /etc/csh.login.site ) source /etc/csh.login.site

	switch ($term)
	case dialup:
	case unknown:
	case network:
		setenv TERM $dterm
		echo $N "Enter terminal type: [$dterm] $C"
		setenv a $<
		if ( $?a && $a != "" ) setenv TERM $a
		set term=$TERM
		breaksw
	case sun*:
		breaksw
	default:
		eval `tset -sQ`
		echo TERM = $term
		set noglob
		breaksw
	endsw

	switch ($term)
	case xterm*:
		stty erase ^?
		breaksw
	case vt*:
		stty erase ^h
		breaksw
	endsw

	# This allows group defaults to override us.
	setenv GROUPDIR `dirname $HOME`
	if ( $GROUPDIR != /etc && -e ${GROUPDIR}/csh.login ) source ${GROUPDIR}/csh.login

	switch ($OS)
	case *BSD:
		breaksw
	case SunOS:
		if ( -x /usr/ucb/Mail ) then
		  if { Mail -e } echo "You have mail."
		endif
		switch ($TTY)
		case console:
		case sun*:
			# tell them about available window systems
			echo "Type 'owin' for OpenWindows, or 'sview' for SunView"
			alias owin	'/usr/openwin/bin/openwin'
			alias sview	'sunview'
			breaksw
		endsw
		breaksw
	case SCO-UNIX:
		if ( -f /etc/motd ) cat /etc/motd
		if ( -x usr/bin/mail && ! -z "$MAIL" ) echo "You have mail."
		if ( -x /usr/bin/news ) /usr/bin/news -n
		breaksw
	default:
		if ( -f /etc/motd ) cat /etc/motd
		if ( -x /usr/bin/mailx ) then
		  if { mailx -e } echo "You have mail."
		endif
		if ( -x /usr/bin/news ) /usr/bin/news -n
		breaksw
	endsw
	if ( -x /usr/games/fortune ) /usr/games/fortune -a

	# we install msgs where we can
	setenv msgs `which msgs`
	if ( $?msgs && $msgs != "" ) $msgs -fq

	# clean up
	unsetenv dterm
	unsetenv a
	unsetenv N
	unsetenv C
endif

if ( ! -w / ) then
	# not root
	if ( -d ${HOME}/bin ) set path=( ${HOME}/bin $path )
	set path=( $path . )
endif

# lots of things break if $term isn't set
if (! $?term ) then
	set term=dumb
	setenv TERM $term
endif

unset noglob
