:
# NAME:
#	uumail.sh - uuencode and mail things
#
# SYNOPSIS:
#	uumail.sh [-v][-s][-h "hunk"] [-t "tmp"][-T "tag"] "dest" "file" ...
#
# DESCRIPTION:
#	Each "file" is uuencoded and mailed to "dest".
#	Unless '-s' is given, each mail item consists of a shell
#	archive that will uudecode its conents at the other end.
#	
#	If "file" is bigger than "hunk" Kbytes it is first split,
#	into smaller parts, each of which is uuencoded and mailed
#	separately, and the shell archive will automagically
#	reconstitute "file" at the other end.
#
#	Each mail item is tagged with "tag" in the subject for the
#	benefit of auto-mail sifters.  The default tag is 'uumail'.
#
# BUGS:
#	Requires shar.sh
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: uumail.sh,v 1.10 2001/08/30 09:55:59 sjg Exp $
#
#	@(#) Copyright (c) 1994 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Myname=`basename $0 .sh`
Mydir=`dirname $0`

PATH=$Mydir:$PATH
export PATH

opt_str=sh:t:vT:
opt_s=1
opt_T=$Myname

rc=.${Myname}rc

for d in $HOME $Mydir
do
        test -s $d/$rc && { . $d/$rc; break; }
done

. setopts.sh

dest=$1; shift;

# make sure these are not empty
opt_h=${opt_h:-42}
opt_t=${opt_t:-/tmp}

MAILER=${MAILER:-`test -x /usr/bin/mailx && echo mailx || echo Mail`}

uushar() {
  f=`basename $1`
  hunks=${2:-0}

  test "x$opt_v" = x ||	echo $MAILER -s "$opt_T: $1" $dest >&2

  case "$opt_s" in
  "")
    uuencode $f < $1
    ;;
  *)
    u=$f.uu
    uuencode $f < $1 > $opt_t/$u
    (
      cd $opt_t
      # this relies on my shar.sh, since we know what
      # its output looks like...
      shar.sh $u | egrep -v '^(exit 0| *fi)'
      cat << !EOC
  else
    echo shar: uudecoding \"$u\"
    uudecode < $u && rm -f $u
!EOC
      if [ $hunks -gt 0 ]; then
        prefix=`basename $3`
        cat <<!EOC
    case \$? in
    0)
      c=\`/bin/ls $prefix.*[0-9] | wc -l\`
      case \`echo \$c\` in
      $hunks)
        echo shar: All $hunks parts present, re-building \"$prefix\"
        cat $prefix.*[0-9] > $prefix
        echo shar: Removing fragments
        rm -f $prefix.*[0-9]
        ;;
      *)
        echo shar: Still need \`expr $hunks - \$c\` of $hunks parts
        ;;
      esac
      ;;
    *)
      shar: uudecode \"$u\" failed!
      ;;
    esac
!EOC
      fi
      echo "  fi"
      echo fi
      echo exit 0
    )
    rm -f $opt_t/$u
    ;;
  esac
}
  
for f in $*
do
  test -f $f || { echo no such file: $f >&2; continue; }
    
  big=`wc -c < $f | awk '{ hunk *= 1024; if ($1 > hunk) { print "yes" } }' hunk=$opt_h -`
  case "$big" in
  yes)
    prefix=$opt_t/`basename $f`
    hunks=`bsplit.sh $prefix $opt_h < $f`
    for h in $prefix.*[0-9]
    do
      uushar $h $hunks $prefix | $MAILER -s "$opt_T: $h of $hunks" $dest
    done
    rm -f $prefix.*[0-9]
    ;;
  *)
    uushar $f | $MAILER -s "$opt_T: $f" $dest
    ;;
  esac
done

