:
# NAME:
#	newsyslog.sh - cycle syslog logs
#
# SYNOPSIS:
#	newsyslog.sh [-N] [logs]
#
# DESCRIPTION:
#	Run from cron, we find all the files that syslogd will be
#	writing to (if they exist) and give them to newlog.sh
#	We pass /etc/syslog.conf through m4(1) incase it is needed.
#
#	Options:
#
#	-N	Don't actually do anything, just show us.
#
#	-M "m4"
#		Use "m4" instead of m4(1).
#
#	-X"opt"
#		Pass "opt" on to 'newlog.sh'.
#
#	-e	Normally logs are only cycled if non-empty, this
#		option forces empty logs to be cycled as well.
#
#	-n "num"
#		Keep "num" generations of "log".
#
#	-m "mode"
#		Set the mode of "log" (default 664).
#
# BUGS:
#	Requires an up to date 'setopts.sh'
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: newsyslog.sh,v 1.6 1999/03/09 12:44:43 sjg Exp $
#
#
#	@(#) Copyright (c) 1994 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Mydir=`dirname $0`

. /etc/add_path.sh
pre_path `dirname $Mydir`/bin
add_path /usr/local/share/bin
add_path /usr/local/bin
add_path /share/bin
add_path /usr/ccs/bin

opt_n=${NEWSYSLOG_N:-14}
opt_m=${NEWSYSLOG_MODE:-664}

case "$NEWSYSLOG_GENS" in
"")	;;
*)	opt_X="-G$NEWSYSLOG_GENS";;
esac

opt_str=Nn:M:m:X.e

. setopts.sh

case "$opt_N" in
"")	ECHO=;;
*)	ECHO=echo;;
esac

logs=$*
myname=`uname -n`
case "$logs" in
"")
	# if the system does not have m4, syslog.conf must not require it.
	M4=$opt_M
	M4=${M4:-`Which gm4`}
	M4=${M4:-`Which m4`}
	M4=${M4:-cat}

	# don't get fooled by #loghost
	logh=`sed 's/#.*//' /etc/hosts | grep loghost`
	logs=`(
	if [ "$M4" != cat ]; then
		# pass /etc/syslog.conf through m4(1),
		# defining LOGHOST if needed,
		# before extracting logfile names.
		case "$logh" in
		""|*localhost*|*$myname*)
			echo "define(LOGHOST, localhost);";;
		esac
	fi
	cat /etc/syslog.conf
	) | $M4 | grep / | egrep -v '/dev|#|@'	| awk '{ print $NF }' | sort -u`
	;;
esac
case "$logs" in
"") exit 0;;			# shouldn't happen
esac
  
newlog.sh $opt_N $opt_e -m$opt_m -n$opt_n $opt_X $logs

pid=
for d in /var/run /etc
do
	test -s $d/syslog.pid && { pid=`cat $d/syslog.pid`; break; }
done

if [ "$pid" ] && $ECHO kill -0 $pid; then
	$ECHO sleep 40
	$ECHO kill -1 $pid
fi
exit 0
